@@ -5,23 +5,18 @@
 #' @param X the number of successes
 #' @param n the total number of observations
 #' @param alpha the nominal level, e.g. 0.05 for 95#' CIs
-#' @param printresults display results (F = no, T = yes)
-#' @return A vector containing lower, upper and point estimates of the statistic
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
 #' @examples
-#'
-#' # The number of 1st order male births (Singh et al. 2010)
-#' ClopperPearson_exact_CI_1x2(X = 250, n = 533)
-#' # The number of 2nd order male births (Singh et al. 2010)
-#' ClopperPearson_exact_CI_1x2(X = 204, n = 412)
-#' # The number of 3rd order male births (Singh et al. 2010)
-#' ClopperPearson_exact_CI_1x2(X = 103, n = 167)
-#' # The number of 4th order male births (Singh et al. 2010)
-#' ClopperPearson_exact_CI_1x2(X = 33, n = 45)
-#' # Ligarden et al. (2010)
-#' ClopperPearson_exact_CI_1x2(X = 13, n = 16)
+#' ClopperPearson_exact_CI_1x2(singh_2010["1st", "X"], singh_2010["1st", "n"])
+#' ClopperPearson_exact_CI_1x2(singh_2010["2nd", "X"], singh_2010["2nd", "n"])
+#' ClopperPearson_exact_CI_1x2(singh_2010["3rd", "X"], singh_2010["3rd", "n"])
+#' with(singh_2010["4th", ], ClopperPearson_exact_CI_1x2(X, n)) # alternative syntax
+#' ClopperPearson_exact_CI_1x2(ligarden_2010["X"], ligarden_2010["n"])
 #' @export
-
-ClopperPearson_exact_CI_1x2 <- function(X, n, alpha = 0.05, printresults = TRUE) {
+ClopperPearson_exact_CI_1x2 <- function(X, n, alpha = 0.05) {
+  validateArguments(mget(ls()))
   # Estimate of the binomial probability (pihat)
   estimate <- X / n
   tol <- 0.00000001
@@ -40,16 +35,19 @@ ClopperPearson_exact_CI_1x2 <- function(X, n, alpha = 0.05, printresults = TRUE)
     U <- uniroot(calculate_U_CP, interval = c(0, 1), X = X, n = n, alpha = alpha, tol = tol)$root
   }
 
-  if (printresults) {
-    print(sprintf(
+  # Output
+  printresults <- function() {
+    my_sprintf_cat(
       "The Clopper Pearson exact CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)",
       estimate, 100 * (1 - alpha), L, U
-    ), quote = FALSE)
+    )
   }
-
-  res <- c(L, U, estimate)
-  names(res) <- c("lower", "upper", "estimate")
-  invisible(res)
+  return(
+    contingencytables_result(
+      list(lower = L, upper = U, estimate = estimate),
+      printresults
+    )
+  )
 }
 
 calculate_L_CP <- function(L0, X, n, alpha) {
