@@ -3,17 +3,15 @@
 #' @description Described in Chapter 4 "The 2x2 Table"
 #' @param n the observed counts (a 2x2 matrix)
 #' @param alpha the nominal level, e.g. 0.05 for 95% CIs
-#' @param printresults display results (FALSE = no, TRUE = yes)
 #' @examples
-#' # A case-control study of GADA exposure on IPEX syndrome (Lampasona et al., 2013):
-#' n <- matrix(c(9, 4, 4, 10), nrow = 2, byrow = TRUE)
-#' Inv_sinh_CI_OR_2x2(n)
-#' # The association between CHRNA4 genotype and XFS (Ritland et al., 2007):
-#' n <- matrix(c(0, 16, 15, 57), nrow = 2, byrow = TRUE)
-#' Inv_sinh_CI_OR_2x2(n)
+#' Inv_sinh_CI_OR_2x2(lampasona_2013)
+#' Inv_sinh_CI_OR_2x2(ritland_2007)
 #' @export
-#' @return A data frame containing lower, upper and point estimates of the statistic
-Inv_sinh_CI_OR_2x2 <- function(n, alpha = 0.05, printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+Inv_sinh_CI_OR_2x2 <- function(n, alpha = 0.05) {
+  validateArguments(mget(ls()))
   # Estimate of the odds ratio (thetahat)
   estimate <- n[1, 1] * n[2, 2] / (n[1, 2] * n[2, 1])
 
@@ -45,16 +43,11 @@ Inv_sinh_CI_OR_2x2 <- function(n, alpha = 0.05, printresults = TRUE) {
     L <- n[1, 1] * n[2, 2] / ((z^2) * (z^2))
   }
 
-  if (printresults) {
-    print(
-      sprintf(
-        "The inverse sinh CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)",
-        estimate, 100 * (1 - alpha), L, U
-      ),
-      quote = FALSE
+  return(contingencytables_result(
+    list("lower" = L, "upper" = U, "estimate" = estimate),
+    sprintf(
+      "The inverse sinh CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)",
+      estimate, 100 * (1 - alpha), L, U
     )
-  }
-
-  res <- data.frame(lower = L, upper = U, estimate = estimate)
-  invisible(res)
+  ))
 }
