@@ -3,16 +3,15 @@
 #' @description Described in Chapter 8 "The Paired 2x2 Table"
 #' @param n the observed counts (a 2x2 matrix)
 #' @param alpha the nominal level, e.g. 0.05 for 95% CIs
-#' @param printresults display results (FALSE = no, TRUE = yes)
 #' @examples
-#'
-#' # Floppy eyelid syndrome vs obstructive sleep apnea (Ezra et al., 2010)
-#' n <- rbind(c(7, 25), c(2, 68))
-#' Wald_CI_OR_paired_2x2(n)
-#'
+#' Wald_CI_OR_paired_2x2(ezra_2010)
 #' @export
-#' @return A list containing lower, upper and point estimates of the statistic
-Wald_CI_OR_paired_2x2 <- function(n, alpha = 0.05, printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+Wald_CI_OR_paired_2x2 <- function(n, alpha = 0.05) {
+  validateArguments(mget(ls()))
+
   # Estimate of the conditional odds ratio (thetacondhat)
   estimate <- n[1, 2] / n[2, 1]
 
@@ -33,14 +32,16 @@ Wald_CI_OR_paired_2x2 <- function(n, alpha = 0.05, printresults = TRUE) {
     U <- Inf
   }
 
-  if (printresults) {
-    .print("The Wald CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)\n", estimate, 100 * (1 - alpha), L, U)
+  printresults <- function() {
+    sprintf(
+      "The Wald CI: estimate = %6.4f (%g%% CI %6.4f to %6.4f)", estimate,
+      100 * (1 - alpha), L, U
+    )
   }
 
-  invisible(list(L = L, U = U, estimate = estimate))
-}
-
-
-.print <- function(s, ...) {
-  print(sprintf(gsub("\n", "", s), ...), quote = FALSE)
+  return(
+    contingencytables_result(
+      list(L = L, U = U, estimate = estimate), printresults
+    )
+  )
 }
