@@ -1,30 +1,27 @@
 #' @title The Wald test and CI for a common ratio of probabilities
 #' @description The Wald test and CI for a common ratio of probabilities
 #' @description based on either the Mantel-Haenszel or inverse variance estimate
-#' @description Described in Chapter 10 "Stratified 2x2 Tables and Meta-Analysis"
+#' @description Described in Chapter 10 "Stratified 2x2 Tables and
+#' Meta-Analysis"
 #' @param n the observed table (a 2x2xk matrix, where k is the number of strata)
-#' @param estimatetype Mantel-Haenszel or inverse variance estimate ('MH' or 'IV')
+#' @param estimatetype Mantel-Haenszel or inverse variance estimate
+#' ('MH' or 'IV')
 #' @param alpha the nominal level, e.g. 0.05 for 95% CIs
-#' @param printresults display results (FALSE = no, TRUE = yes)
 #' @examples
 #' # Smoking and lung cancer (Doll and Hill, 1950)
-#' n <- array(dim = c(2, 2, 2))
-#' n[, , 1] <- matrix(c(647, 622, 2, 27), 2, byrow = TRUE)
-#' n[, , 2] <- matrix(c(41, 28, 19, 32), 2, byrow = TRUE)
-#' Wald_test_and_CI_common_ratio_stratified_2x2(n)
+#' Wald_test_and_CI_common_ratio_stratified_2x2(doll_hill_1950)
 #'
 #' # Prophylactice use of Lidocaine in myocardial infarction (Hine et al., 1989)
-#' n <- array(0, dim = c(2, 2, 6))
-#' n[, , 1] <- rbind(c(2, 37), c(1, 42))
-#' n[, , 2] <- rbind(c(4, 40), c(4, 40))
-#' n[, , 3] <- rbind(c(6, 101), c(4, 106))
-#' n[, , 4] <- rbind(c(7, 96), c(5, 95))
-#' n[, , 5] <- rbind(c(7, 103), c(3, 103))
-#' n[, , 6] <- rbind(c(11, 143), c(4, 142))
-#' Wald_test_and_CI_common_ratio_stratified_2x2(n)
+#' Wald_test_and_CI_common_ratio_stratified_2x2(hine_1989)
 #' @export
-#' @return A list containing the two-sided p-value, the Wald test statistic, and the lower, upper and point estimates for phi
-Wald_test_and_CI_common_ratio_stratified_2x2 <- function(n, estimatetype = "MH", alpha = 0.05, printresults = TRUE) {
+#' @return An object of the [contingencytables_result] class,
+#' basically a subclass of [base::list()]. Use the [utils::str()] function
+#' to see the specific elements returned.
+Wald_test_and_CI_common_ratio_stratified_2x2 <- function(
+  n, estimatetype = "MH", alpha = 0.05
+) {
+  validateArguments(mget(ls()))
+
   n1pk <- apply(n[1, , ], 2, sum)
   np1k <- apply(n[, 1, ], 2, sum)
   n2pk <- apply(n[2, , ], 2, sum)
@@ -32,9 +29,9 @@ Wald_test_and_CI_common_ratio_stratified_2x2 <- function(n, estimatetype = "MH",
 
   # Get the MH or IV overall estimates (and the weights for the IV)
   if (identical(estimatetype, "MH")) {
-    phihat <- MantelHaenszel_estimate_stratified_2x2(n, "log", FALSE)[[1]]
+    phihat <- MantelHaenszel_estimate_stratified_2x2(n, "log")[[1]]
   } else if (identical(estimatetype, "IV")) {
-    tmp <- InverseVariance_estimate_stratified_2x2(n, "log", FALSE)
+    tmp <- InverseVariance_estimate_stratified_2x2(n, "log")
     phihat <- tmp[[1]]
     v <- tmp[[3]]
   }
@@ -62,15 +59,21 @@ Wald_test_and_CI_common_ratio_stratified_2x2 <- function(n, estimatetype = "MH",
   L <- phihat * exp(-z_alpha * SElog)
   U <- phihat * exp(z_alpha * SElog)
 
-  if (printresults) {
-    .print("The Wald test (%s): P = %7.5f, Z = %6.3f\n", estimatetype, P, Z)
-    .print("The Wald CI (%s): phihat = %6.4f (%g%% CI %6.4f to %6.4f)\n", estimatetype, phihat, 100 * (1 - alpha), L, U)
+  printresults <- function() {
+    cat(
+      sprintf("The Wald test (%s): P = %7.5f, Z = %6.3f\n", estimatetype, P, Z)
+    )
+    cat(
+      sprintf(
+        "The Wald CI (%s): phihat = %6.4f (%g%% CI %6.4f to %6.4f)",
+        estimatetype, phihat, 100 * (1 - alpha), L, U
+      )
+    )
   }
 
-  invisible(list(P = P, Z = Z, L = L, U = U, phihat = phihat))
-}
-
-
-.print <- function(s, ...) {
-  print(sprintf(gsub("\n", "", s), ...), quote = FALSE)
+  return(
+    contingencytables_result(
+      list(P = P, Z = Z, L = L, U = U, phihat = phihat), printresults
+    )
+  )
 }
